==> espresso_6.0.orig.tar.gz: qe-6.0/atomic/Doc/pseudo-gen/labels.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate labels original text with physical files.


$key = q/cite_PAW/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/ValCore/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_NC/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/radii/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_TM/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/pseudization/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_fhi98PP/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_van/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Gonze/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/RefConf/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/XC/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Goedecker/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Zunger/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_BHS/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_CoreCorr/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_RRKJ/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/pseudiz/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/nlcc/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_KB/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/trans/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2008 (1.71)
# labels from external_latex_labels array.


$key = q/pseudization/;
$external_latex_labels{$key} = q|2.2|; 
$noresave{$key} = "$nosave";

$key = q/radii/;
$external_latex_labels{$key} = q|2.2.2|; 
$noresave{$key} = "$nosave";

$key = q/ValCore/;
$external_latex_labels{$key} = q|2.1.2|; 
$noresave{$key} = "$nosave";

$key = q/nlcc/;
$external_latex_labels{$key} = q|2.1.4|; 
$noresave{$key} = "$nosave";

$key = q/pseudiz/;
$external_latex_labels{$key} = q|2.2.1|; 
$noresave{$key} = "$nosave";

$key = q/XC/;
$external_latex_labels{$key} = q|2.1.1|; 
$noresave{$key} = "$nosave";

$key = q/trans/;
$external_latex_labels{$key} = q|2.4|; 
$noresave{$key} = "$nosave";

$key = q/RefConf/;
$external_latex_labels{$key} = q|2.1.3|; 
$noresave{$key} = "$nosave";

1;

==> espresso_6.7.orig.tar.gz: qe-6.7/atomic/Doc/pseudo-gen/labels.pl <==
# LaTeX2HTML 2019.2 (Released June 5, 2019)
# Associate labels original text with physical files.


$key = q/RefConf/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/ValCore/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/XC/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_BHS/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_CoreCorr/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Goedecker/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Gonze/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_KB/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_NC/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_PAW/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_RRKJ/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Reis/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_TM/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_Zunger/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_fhi98PP/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/cite_van/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/nlcc/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/pseudiz/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/pseudization/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/radii/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/trans/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2019.2 (Released June 5, 2019)
# labels from external_latex_labels array.


$key = q/RefConf/;
$external_latex_labels{$key} = q|2.1.3|; 
$noresave{$key} = "$nosave";

$key = q/ValCore/;
$external_latex_labels{$key} = q|2.1.2|; 
$noresave{$key} = "$nosave";

$key = q/XC/;
$external_latex_labels{$key} = q|2.1.1|; 
$noresave{$key} = "$nosave";

$key = q/nlcc/;
$external_latex_labels{$key} = q|2.1.4|; 
$noresave{$key} = "$nosave";

$key = q/pseudiz/;
$external_latex_labels{$key} = q|2.2.1|; 
$noresave{$key} = "$nosave";

$key = q/pseudization/;
$external_latex_labels{$key} = q|2.2|; 
$noresave{$key} = "$nosave";

$key = q/radii/;
$external_latex_labels{$key} = q|2.2.2|; 
$noresave{$key} = "$nosave";

$key = q/trans/;
$external_latex_labels{$key} = q|2.4|; 
$noresave{$key} = "$nosave";

1;
